# Videodrome
Videodrome generates static media centers in Python with HTML5 user interface.

See the [demo](https://p5yb14d3.github.io/videodrome/demo.html)

[![Screenshot](https://i.imgur.com/7xSayQ4.jpg)](https://p5yb14d3.github.io/videodrome/demo.html)

## Installation
Requires Python 2.7 installed with pip.

`$ pip install videodrome`

## Running Videodrome
`$ videodrome generate <path to your video folder>`

## Input Devices
Works with the keyboard, mouse or [TV Remote](https://www.amazon.com/REDGO-Portable-Wireless-Keyboard-Multifunctional/dp/B06XPYT52B/) 

## MIT License

## Author
The project was authored by p5yb14d3